
var m_vLocalVideo;
var m_vLocalStream;
var m_vRemoteVideo;
var m_vRemoteAudio;

var m_vPeerConnection = null;
var m_bActivatedMedia = false;

function cVaxWebRTC() 
{

    //////////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////

    this.OnPageLoadWebRTC = function () 
    {
        m_vLocalVideo = document.getElementById('Preview');
        m_vRemoteVideo = document.getElementById('RemoteVideo');

        m_vRemoteAudio = document.getElementById('RemoteAudio');

        m_vLocalVideo.addEventListener('loadedmetadata', function () 
        {
            trace('Local video videoWidth: ' + this.videoWidth +
        	'px,  videoHeight: ' + this.videoHeight + 'px');
        });

        m_vRemoteVideo.addEventListener('loadedmetadata', function () 
        {
            trace('Remote video videoWidth: ' + this.videoWidth +
        	'px,  videoHeight: ' + this.videoHeight + 'px');
        });

        m_vRemoteVideo.onresize = function () 
        {
            trace('Remote video size changed to ' +
        	m_vRemoteVideo.videoWidth + 'x' + m_vRemoteVideo.videoHeight);

            if (startTime) 
            {
                var elapsedTime = window.performance.now() - startTime;
                trace('Setup time: ' + elapsedTime.toFixed(3) + 'ms');
                startTime = null;
            }
        };
    }

    //////////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////

    this.OfferCreateWebRTC = function () 
    {
        var servers = null;
        m_vPeerConnection = new RTCPeerConnection(servers);

        m_vPeerConnection.ontrack = m_objVaxWebRTC.gotRemoteStream;
        m_vLocalStream.getTracks().forEach(track => m_vPeerConnection.addTrack(track, m_vLocalStream));

        m_vPeerConnection.createOffer().then(onCreateOfferSuccess, onCreateSessionDescriptionError);
    }

    this.OnOfferCreatedSuccessWebRTC = function (sLocalSDP) 
    {
        m_objVaxFuncSIP.OnOfferCreatedSuccessWebRTC(sLocalSDP);
    }

    this.OnOfferCreatedFailedWebRTC = function (error) 
    {
        m_objVaxFuncSIP.OnOfferCreatedFailedWebRTC(error);
    }

    this.SetOfferRemoteWebRTC = function (sRemoteSDP) 
    {
        var vWebSDP = { sdp: "", type: "" };

        vWebSDP.sdp = sRemoteSDP;
        vWebSDP.type = "answer";

        m_vPeerConnection.setRemoteDescription(vWebSDP, function () 
        {
            onSetRemoteSuccess();

        }, onSetRemoteFailed);
    }

    //////////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////

    this.gotRemoteStream = function (e) 
    {
        m_vRemoteAudio.srcObject = e.streams[0];
        m_vRemoteVideo.srcObject = e.streams[0];
    }

    this.CloseConnection = function () 
    {
        m_vPeerConnection.close();
        m_vPeerConnection = null;
    }

    this.ActivateMediaWebRTC = function()
    {
        ActivateMedia();
    }

    this.DeactivateMediaWebRTC = function()
    {
        DeactivateMedia();
    }

    //////////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////

    function gotStream(stream) 
    {
        m_vLocalVideo.srcObject = stream;
        m_vLocalStream = stream;
    }

    function onCreateSessionDescriptionError(error) 
    {
        m_objVaxWebRTC.OnOfferCreatedFailedWebRTC(error);
    }

    async function onCreateOfferSuccess(desc) 
    {
        try
        {
            await m_vPeerConnection.setLocalDescription(desc);
            onSetLocalDescSuccess();
        }

        catch(e)
        {
            onSetSessionDescError(e);
        }
    }

    function onSetLocalDescSuccess() 
    {
        m_objVaxWebRTC.OnOfferCreatedSuccessWebRTC(m_vPeerConnection.localDescription.sdp);
    }

    function onSetSessionDescError(error) 
    {
        m_objVaxWebRTC.OnOfferCreatedFailedWebRTC(error);
    }

    function onSetRemoteSuccess() 
    {
        //trace(getName(pc) + ' setRemoteDescription complete');
    }

    function onSetRemoteFailed(error) 
    {
        ShowDialog("Failed to set remote session description: " + error.toString());
    }

    //////////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////

    function ActivateMedia()
    {
        if (m_bActivatedMedia)
            return;

        m_bActivatedMedia = true;

        navigator.mediaDevices.getUserMedia({ audio: true, video: true })
        .then(gotStream)
        .catch(function (e)
        {
            m_bActivatedMedia = true;

            navigator.mediaDevices.getUserMedia({ audio: true, video: false })
            .then(gotStream)
            .catch(function (e)
            {
                m_bActivatedMedia = false;
                ShowDialog('Unable to capture media device: ' + e.name);
            });
        });
    }
	
    function DeactivateMedia()
    {
        if (!m_bActivatedMedia)
            return;

        m_bActivatedMedia = false;

        m_vLocalStream.getTracks().forEach(function (track) { track.stop(); });
        m_vLocalVideo.srcObject = null;

        //attachMediaStream(m_vLocalVideo, null);
    }

    //////////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////

    //////////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////////

    var sdpConstraints =
    {
        'mandatory':
        {
            'OfferToReceiveAudio': true,
            'OfferToReceiveVideo': true
        }
    };

    this.AnswerCreateWebRTC = function (sSDP) 
    {        
        var servers = null;
        m_vPeerConnection = new RTCPeerConnection(servers);

        m_vPeerConnection.ontrack = m_objVaxWebRTC.gotRemoteStream;
        m_vLocalStream.getTracks().forEach(track => m_vPeerConnection.addTrack(track, m_vLocalStream));

        var SDP = { sdp: "", type: "" };

        SDP.sdp = sSDP;
        SDP.type = "offer";

        m_vPeerConnection.setRemoteDescription(SDP, function () 
        {
            onSetRemoteSuccess();

        }, onSetSessionDescriptionError);

        m_vPeerConnection.createAnswer().then(onCreateAnswerSuccess, onCreateSessionDescriptionError, sdpConstraints);
    }

    this.OnAnswerCreatedSuccessWebRTC = function (sLocalSDP) 
    {
        m_objVaxEventSIP.OnAnswerCreatedSuccessWebRTC(sLocalSDP);
    }

    this.OnAnswerCreatedFailedWebRTC = function (error) 
    {
        m_objVaxEventSIP.OnAnswerCreatedFailedWebRTC(error);
    }

    function onSetRemoteSuccess() 
    {
        
    }

    function onSetSessionDescriptionError(error) 
    {
        m_objVaxWebRTC.OnAnswerCreatedFailedWebRTC(error);
    }

    async function onCreateAnswerSuccess(desc) 
    {
        try
        {
            await m_vPeerConnection.setLocalDescription(desc);
            onSetLocalSuccessAnswer();
        }

        catch(e)
        {
            onSetSessionDescriptionError(e);
        }
    }

    function onSetLocalSuccessAnswer() 
    {
        m_objVaxWebRTC.OnAnswerCreatedSuccessWebRTC(m_vPeerConnection.localDescription.sdp);
    }
}